#ifndef KBUTTONBOX_H
#define KBUTTONBOX_H

#include "gui_g.h"
#include "kpushbutton.h"
#include <QWidget>
#include <QAbstractButton>


namespace kdk {

class KButtonBoxPrivate;

class GUI_EXPORT KButtonBox : public QWidget
{
    Q_OBJECT

public:
    explicit KButtonBox(QWidget *parent = nullptr);
    ~KButtonBox();

    /**
     * @brief 获取KButtonBox的布局类型
     * @return
     */
    Qt::Orientation orientation();

    /**
     * @brief 设置KButtonBox的布局类型,包括水平类型和垂直类型
     * @param orientation
     */
    void setOrientation(Qt::Orientation orientation);

    /**
     * @brief 添加按钮
     * @param button
     */
    void addButton(KPushButton *button,int i = -1);

    /**
     * @brief 删除按钮
     * @param button
     */
    void removeButton(KPushButton *button);

    /**
     * @brief 按id删除指定按钮
     * @param i
     */
    void removeButton(int i);

    /**
     * @brief 以列表形式向KButtonBox中添加按钮
     * @param list
     * @param checkable
     */
    void setButtonList(const QList<KPushButton*> &list);

    /**
     * @brief 获取KButtonBox中的按钮列表
     * @return
     */
    QList<KPushButton *> buttonList();

    /**
     * @brief 设置KButtonBox首尾部分按钮的圆角
     * @param radius
     */
    void setBorderRadius(int radius);

    /**
     * @brief 获取KButtonBox首尾部分按钮的圆角
     * @return
     */
    int borderRadius();

    /**
     * @brief 设置按钮id
     * @param button
     * @param id
     */
    void setId(KPushButton *button, int id);

    /**
     * @brief 获取按钮id
     * @param button
     * @return
     */
    int id(KPushButton *button);

    /**
     * @brief 返回已选中的按钮
     * @return
     */
    KPushButton * checkedButton();

    /**
     * @brief 通过按钮id获取按钮
     * @param id
     * @return
     */
    KPushButton *button(int id);

    /**
     * @brief 返回已选中按钮的id
     * @return
     */
    int checkedId();

    /**
     * @brief 设置KButtonBox按钮间是否互斥
     */
    void setExclusive(bool);

    /**
     * @brief 返回KButtonBox按钮间是否互斥
     * @return
     */
    bool exclusive();

    /**
     * @brief 设置KButtonBox中的按钮是否可选中
     */
    void setCheckable(bool flag);

    /**
     * @brief 返回KButtonBox中的按钮是否可选中
     * @return
     */
    bool isCheckable();

Q_SIGNALS:
    void buttonClicked(QAbstractButton *);
    void buttonPressed(QAbstractButton *);
    void buttonReleased(QAbstractButton *);
    void buttonToggled(QAbstractButton *, bool);

private:
    Q_DECLARE_PRIVATE(KButtonBox)
    KButtonBoxPrivate* const d_ptr;
};

}
#endif // KBUTTONBOX_H
